@@ -10,7 +10,7 @@ fn test() {
     let mut cx = task::noop_context();
 
     let mut sub1 = WATCH.subscribe();
-    let mut get1 = Box::pin(sub1.get());
+    let mut get1 = Box::pin(sub1.changed());
     assert!(Pin::new(&mut get1).poll(&mut cx).is_pending());
     assert!(Pin::new(&mut get1).poll(&mut cx).is_pending());
     WATCH.try_send(1).unwrap();
@@ -18,9 +18,9 @@ fn test() {
 
     let mut sub2 = WATCH.subscribe();
     let mut sub3 = WATCH.subscribe();
-    let mut get2 = Box::pin(sub2.get());
+    let mut get2 = Box::pin(sub2.changed());
     WATCH.try_send(2).unwrap();
-    let mut get3 = Box::pin(sub3.get());
+    let mut get3 = Box::pin(sub3.changed());
     assert_eq!(Pin::new(&mut get2).poll(&mut cx), Poll::Ready(2));
     assert_eq!(Pin::new(&mut get3).poll(&mut cx), Poll::Ready(2));
 }
